@@ -48,7 +48,6 @@ from beer_garden.api.http.authorization import anonymous_principal as load_anony
 from beer_garden.api.http.client import SerializeHelper
 from beer_garden.api.http.processors import EventManager, websocket_publish
 from beer_garden.events import publish
-from beer_garden.events.processors import QueueListener
 
 io_loop: IOLoop = None
 server: HTTPServer
@@ -65,7 +64,6 @@ def run(ep_conn):
     logger = logging.getLogger(__name__)
 
     _setup_application()
-    _setup_operation_forwarding()
     _setup_event_handling(ep_conn)
 
     # Schedule things to happen after the ioloop comes up
@@ -95,10 +93,7 @@ async def startup():
     logger.debug(f"Starting HTTP server on {http_config.host}:{http_config.port}")
     server.listen(http_config.port, http_config.host)
 
-    logger.debug("Starting forward processor")
-    beer_garden.router.forward_processor.start()
-
-    beer_garden.api.http.logger.info("Http entry point is started. Hello!")
+    logger.info("Http entry point started")
 
     publish(
         Event(name=Events.ENTRY_STARTED.name, metadata={"entry_point_type": "HTTP"})
@@ -120,9 +115,6 @@ async def shutdown():
     logger.debug("Stopping server for new HTTP connections")
     server.stop()
 
-    logger.debug("Stopping forward processing")
-    beer_garden.router.forward_processor.stop()
-
     # This will almost definitely not be published to the websocket, because it would
     # need to make it up to the main process and back down into this process. We just
     # publish this here in case the main process is looking for it.
@@ -208,12 +200,20 @@ def _setup_tornado_app() -> Application:
         (rf"{prefix}api/v1/jobs/(\w+)/?", v1.job.JobAPI),
         (rf"{prefix}api/v1/logging/?", v1.logging.LoggingAPI),
         (rf"{prefix}api/v1/gardens/([\w%]+)/?", v1.garden.GardenAPI),
-        (rf"{prefix}api/v1/files/?", v1.file.FileAPI),
-        (rf"{prefix}api/v1/files/id/?", v1.file.FileNameAPI),
         # Beta
         (rf"{prefix}api/vbeta/events/?", vbeta.event.EventPublisherAPI),
         (rf"{prefix}api/vbeta/runners/?", vbeta.runner.RunnerListAPI),
         (rf"{prefix}api/vbeta/runners/(\w+)/?", vbeta.runner.RunnerAPI),
+        (
+            rf"{prefix}api/vbeta/chunks/?",
+            beer_garden.api.http.handlers.vbeta.chunk.FileChunkAPI,
+        ),
+        (
+            rf"{prefix}api/vbeta/chunks/id/?",
+            beer_garden.api.http.handlers.vbeta.chunk.ChunkNameAPI,
+        ),
+        (rf"{prefix}api/vbeta/file/?", vbeta.file.RawFileListAPI),
+        (rf"{prefix}api/vbeta/file/(\w+)/?", vbeta.file.RawFileAPI),
         # V2
         (rf"{prefix}api/v2/users/?", v1.user.UsersAPI),
         (rf"{prefix}api/v2/users/(\w+)/?", v1.user.UserAPI),
@@ -348,14 +348,6 @@ def _load_swagger(url_specs, title=None):
         api_spec.add_path(urlspec=url_spec)
 
 
-def _setup_operation_forwarding():
-    # Create a forwarder to push operations to child gardens
-    # TODO - This thing is another thread. Asyncing it would be nice
-    beer_garden.router.forward_processor = QueueListener(
-        action=beer_garden.router.forward
-    )
-
-
 def _setup_event_handling(ep_conn):
     # This will push all events generated in the entry point up to the master process
     beer_garden.events.manager = EventManager(ep_conn)
