@@ -219,6 +219,7 @@ class Command(MongoModel, EmbeddedDocument):
     template = StringField()
     hidden = BooleanField()
     icon_name = StringField()
+    metadata = DictField()
 
     def clean(self):
         """Validate before saving to the database"""
@@ -493,6 +494,7 @@ class System(MongoModel, Document):
     display_name = StringField()
     metadata = DictField()
     local = BooleanField(default=True)
+    template = StringField()
 
     meta = {
         "auto_create_index": False,  # We need to manage this ourselves
@@ -684,6 +686,7 @@ class Job(MongoModel, Document):
         required=True, choices=BrewtilsJob.STATUS_TYPES, default="RUNNING"
     )
     max_instances = IntField(default=3, min_value=1)
+    timeout = IntField()
 
     def clean(self):
         """Validate before saving to the database"""
@@ -757,3 +760,7 @@ class FileChunk(MongoModel, Document):
     data = StringField(required=True)
     # Delete Rule (2) = CASCADE; This causes this document to be deleted when the owner doc is.
     owner = LazyReferenceField(File, required=False, reverse_delete_rule=CASCADE)
+
+
+class RawFile(Document):
+    file = FileField()
