@@ -511,8 +511,6 @@ class RequestValidator(object):
                 return int(value)
             elif parameter.type.upper() == "FLOAT":
                 return float(value)
-            elif parameter.type.upper() == "ANY":
-                return value
             elif parameter.type.upper() == "BOOLEAN":
                 if value in [True, False]:
                     return value
@@ -530,7 +528,7 @@ class RequestValidator(object):
                 return int(value)
             elif parameter.type.upper() == "DATETIME":
                 return int(value)
-            elif parameter.type.upper() == "BASE64":
+            elif parameter.type.upper() in ("ANY", "BASE64", "BYTES"):
                 return value
             else:
                 raise ModelValidationError(
@@ -609,28 +607,27 @@ def process_request(
             f"brewtils.models.Request or brewtils.models.RequestTemplate,"
         )
 
-    # Validates the request based on what is in the database.
-    # This includes the validation of the request parameters,
-    # systems are there, commands are there etc.
     # Validation is only required for non Admin commands because Admin commands
     # are hard coded to map Plugin functions
     if not is_admin:
-        request = RequestValidator.instance().validate_request(request)
+        try:
+            request = RequestValidator.instance().validate_request(request)
+        except ModelValidationError:
+            invalid_request(request)
+            raise
 
-    # Save after validation since validate can modify the request
-    if not request.command_type == "EPHEMERAL":
+    if request.command_type == "EPHEMERAL":
+        logger.debug(f"Publishing {request!r}")
+    else:
+        # Save after validation since validate can modify the request
         request = create_request(request)
 
-    if wait_event:
-        request_map[request.id] = wait_event
+        logger.info(f"Publishing {request!r}")
+
+        if wait_event:
+            request_map[request.id] = wait_event
 
     try:
-        if logger.isEnabledFor(logging.DEBUG):
-            logger.debug(f"Publishing {request!r}")
-        else:
-            if not request.command_type == "EPHEMERAL":
-                logger.info(f"Publishing {request!r}")
-
         queue.put(
             request,
             is_admin=is_admin,
@@ -644,8 +641,8 @@ def process_request(
         if not request.command_type == "EPHEMERAL":
             db.delete(request)
 
-        if wait_event:
-            request_map.pop(request.id, None)
+            if wait_event:
+                request_map.pop(request.id, None)
 
         raise RequestPublishException(
             f"Error while publishing {request!r} to message broker"
@@ -751,6 +748,12 @@ def cancel_request(request_id: str = None, request: Request = None) -> Request:
     return request
 
 
+@publish_event(Events.REQUEST_UPDATED)
+def invalid_request(request: Request = None):
+    request.status = "INVALID"
+    return request
+
+
 def process_wait(request: Request, timeout: float) -> Request:
     """Helper to process a request and wait for completion using a threading.Event
 
@@ -804,11 +807,13 @@ def handle_event(event):
                 request_map[request_event].set()
 
     # Only care about downstream garden
-    elif event.garden != config.get("garden.name"):
+    elif event.garden != config.get("garden.name") and not event.error:
         if event.name in (
             Events.REQUEST_CREATED.name,
             Events.REQUEST_STARTED.name,
             Events.REQUEST_COMPLETED.name,
+            Events.REQUEST_UPDATED.name,
+            Events.REQUEST_CANCELED.name,
         ):
             # When we send child requests to child gardens where the parent was on
             # the local garden we remove the parent before sending them. Only setting
@@ -829,8 +834,3 @@ def handle_event(event):
                     db.create(event.payload)
                 except NotUniqueException:
                     pass
-
-    # Required if the main process spawns a wait Request
-    if event.name == Events.REQUEST_COMPLETED.name:
-        if str(event.payload.id) in request_map:
-            request_map[str(event.payload.id)].set()
